@@ -3,8 +3,9 @@ from typing import Union
 
 from twisted.internet.defer import Deferred
 
-from peek_core_search._private.storage.SearchObjectTypeTuple import \
-    SearchObjectTypeTuple
+from peek_core_search._private.storage.SearchObjectTypeTuple import (
+    SearchObjectTypeTuple,
+)
 from vortex.DeferUtil import deferToThreadWrapWithLogger
 from vortex.Payload import Payload
 from vortex.TupleSelector import TupleSelector
@@ -18,16 +19,16 @@ class SearchObjectTypeTupleProvider(TuplesProviderABC):
         self._ormSessionCreator = ormSessionCreator
 
     @deferToThreadWrapWithLogger(logger)
-    def makeVortexMsg(self, filt: dict,
-                      tupleSelector: TupleSelector) -> Union[Deferred, bytes]:
+    def makeVortexMsg(
+        self, filt: dict, tupleSelector: TupleSelector
+    ) -> Union[Deferred, bytes]:
 
         session = self._ormSessionCreator()
         try:
             tuples = (
-                session
-                    .query(SearchObjectTypeTuple)
-                    .order_by(SearchObjectTypeTuple.order, SearchObjectTypeTuple.title)
-                    .all()
+                session.query(SearchObjectTypeTuple)
+                .order_by(SearchObjectTypeTuple.order, SearchObjectTypeTuple.title)
+                .all()
             )
 
             # Create the vortex message
