@@ -6,7 +6,7 @@ INDEX_BUCKET_COUNT = 8192
 OBJECT_BUCKET_COUNT = 8192
 
 
-def makeSearchIndexChunkKey(key: str) -> int:
+def makeSearchIndexChunkKey(key: str) -> str:
     """Make Chunk Key
 
     This is simple, and provides a reasonable distribution
@@ -25,12 +25,10 @@ def makeSearchIndexChunkKey(key: str) -> int:
         bucket = ((bucket << 5) - bucket) + ord(char)
         bucket = bucket | 0  # This is in the javascript code.
 
-    bucket = bucket & (INDEX_BUCKET_COUNT - 1)
-
-    return bucket
+    return str(bucket & (INDEX_BUCKET_COUNT - 1))
 
 
-def makeSearchObjectChunkKey(key: int) -> int:
+def makeSearchObjectChunkKey(key: int) -> str:
     """Make Chunk Key
 
     This is simple, and provides a reasonable distribution
@@ -44,6 +42,4 @@ def makeSearchObjectChunkKey(key: int) -> int:
     if key is None:
         raise Exception("key is None")
 
-    bucket = key & (OBJECT_BUCKET_COUNT - 1)
-
-    return bucket
+    return str(key & (OBJECT_BUCKET_COUNT - 1))
