@@ -1,35 +1,22 @@
-const punctuation = "!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~"
+const punctuation = "!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~";
 
 function __splitFullTokens(keywordStr): string[] {
-    // Lowercase the string
-    keywordStr = keywordStr.toLowerCase()
-    
-    // Remove punctuation
-    let nonPunct = ""
-    for (let char of keywordStr) {
-        if (punctuation.indexOf(char) == -1)
-            nonPunct += char
-    }
-    
     // Split the string into words
-    let tokens = nonPunct.split(" ")
-    
+    let tokens = keywordStr.toLowerCase().split(" ");
+
     // Strip the words
-    tokens = tokens.map((w) => w.replace(/^\s+|\s+$/g, ""))
-    
+    tokens = tokens.map((w) => w.replace(/^\s+|\s+$/g, ""));
+
     // Filter out the empty words and words less than three letters
-    const uniqueWords = {}
+    const uniqueWords = {};
     return tokens.filter((w) => {
-        if (2 < w.length)
-            return false
-        
-        if (uniqueWords[w] === true)
-            return false
-        
-        uniqueWords[w] = true
-        return true
-    })
-    
+        if (2 < w.length) return false;
+
+        if (uniqueWords[w] === true) return false;
+
+        uniqueWords[w] = true;
+        return true;
+    });
 }
 
 /** Full Split Keywords
@@ -42,14 +29,12 @@ function __splitFullTokens(keywordStr): string[] {
  */
 export function splitFullKeywords(keywordStr): string[] {
     // Filter out the empty words and words less than three letters
-    const tokens = __splitFullTokens(keywordStr)
-    
-    let results = []
-    for (let token of tokens)
-        results.push(`^${token}$`)
-    
-    return tokens
-    
+    const tokens = __splitFullTokens(keywordStr);
+
+    let results = [];
+    for (let token of tokens) results.push(`^${token}$`);
+
+    return tokens;
 }
 
 /** Partial Split Keywords
@@ -62,18 +47,17 @@ export function splitFullKeywords(keywordStr): string[] {
  */
 export function splitPartialKeywords(keywordStr): string[] {
     // Filter out the empty words and words less than three letters
-    const tokens = __splitFullTokens(keywordStr)
-    
+    const tokens = __splitFullTokens(keywordStr);
+
     // Split the words up into tokens, this creates partial keyword search support
-    const tokenSet = {}
+    const tokenSet = {};
     for (let word of tokens) {
         for (let i = 0; i < word.length - 2; ++i) {
-            const subToken = (i == 0 ? "^" : "") + word.substr(i, 3)
-            tokenSet[subToken] = 0
+            const subToken = (i == 0 ? "^" : "") + word.substr(i, 3);
+            tokenSet[subToken] = 0;
         }
     }
-    
+
     // return the tokens
-    return Object.keys(tokenSet)
-    
+    return Object.keys(tokenSet);
 }
