@@ -1,3 +1,5 @@
+import { Observable, Subject } from "rxjs";
+import { filter, first, takeUntil } from "rxjs/operators";
 import { Injectable } from "@angular/core";
 import {
     extend,
@@ -10,7 +12,6 @@ import {
     TupleStorageFactoryService,
     VortexService,
     VortexStatusService,
-    TupleStorageBatchSaveArguments,
 } from "@synerty/vortexjs";
 import {
     searchFilt,
@@ -18,14 +19,15 @@ import {
     searchTuplePrefix,
 } from "../PluginNames";
 
-import { Observable, Subject } from "rxjs";
-
 import { EncodedSearchIndexChunkTuple } from "./EncodedSearchIndexChunkTuple";
 import { SearchIndexUpdateDateTuple } from "./SearchIndexUpdateDateTuple";
-import { OfflineConfigTuple } from "../tuples/OfflineConfigTuple";
 import { SearchTupleService } from "../SearchTupleService";
 import { PrivateSearchIndexLoaderStatusTuple } from "./PrivateSearchIndexLoaderStatusTuple";
 import { splitFullKeywords, splitPartialKeywords } from "../KeywordSplitter";
+import {
+    DeviceOfflineCacheControllerService,
+    OfflineCacheStatusTuple,
+} from "@peek/peek_core_device";
 
 // ----------------------------------------------------------------------------
 
@@ -45,7 +47,7 @@ const cacheAll = "cacheAll";
 // There is actually no tuple here, it's raw JSON,
 // so we don't have to construct a class to get the data
 class SearchIndexChunkTupleSelector extends TupleSelector {
-    constructor(private chunkKey: number) {
+    constructor(private chunkKey: string) {
         super(searchTuplePrefix + "SearchIndexChunkTuple", { key: chunkKey });
     }
 
@@ -70,7 +72,7 @@ class UpdateDateTupleSelector extends TupleSelector {
  */
 let INDEX_BUCKET_COUNT = 8192;
 
-function keywordChunk(keyword: string): number {
+function keywordChunk(keyword: string): string {
     /** keyword
      
      This method creates an int from 0 to MAX, representing the hash bucket for this
@@ -93,9 +95,7 @@ function keywordChunk(keyword: string): number {
         bucket |= 0; // Convert to 32bit integer
     }
 
-    bucket = bucket & (INDEX_BUCKET_COUNT - 1);
-
-    return bucket;
+    return (bucket & (INDEX_BUCKET_COUNT - 1)).toString();
 }
 
 // ----------------------------------------------------------------------------
@@ -124,32 +124,15 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
     private _statusSubject = new Subject<PrivateSearchIndexLoaderStatusTuple>();
     private _status = new PrivateSearchIndexLoaderStatusTuple();
 
-    private offlineConfig: OfflineConfigTuple = new OfflineConfigTuple();
-
     constructor(
         private vortexService: VortexService,
         private vortexStatusService: VortexStatusService,
         storageFactory: TupleStorageFactoryService,
-        private tupleService: SearchTupleService
+        private tupleService: SearchTupleService,
+        private deviceCacheControllerService: DeviceOfflineCacheControllerService
     ) {
         super();
 
-        this.tupleService.offlineObserver
-            .subscribeToTupleSelector(
-                new TupleSelector(OfflineConfigTuple.tupleName, {}),
-                false,
-                false,
-                true
-            )
-            .takeUntil(this.onDestroyEvent)
-            .filter((v) => v.length != 0)
-            .subscribe((tuples: OfflineConfigTuple[]) => {
-                this.offlineConfig = tuples[0];
-                if (this.offlineConfig.cacheChunksForOffline)
-                    this.initialLoad();
-                this._notifyStatus();
-            });
-
         this.storage = new TupleOfflineStorageService(
             storageFactory,
             new TupleOfflineStorageNameService(searchIndexCacheStorageName)
@@ -158,10 +141,13 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
         this.setupVortexSubscriptions();
         this._notifyStatus();
 
-        // Check for updates every so often
-        Observable.interval(this.OFFLINE_CHECK_PERIOD_MS)
-            .takeUntil(this.onDestroyEvent)
-            .subscribe(() => this.askServerForUpdates());
+        this.deviceCacheControllerService.triggerCachingObservable
+            .pipe(takeUntil(this.onDestroyEvent))
+            .pipe(filter((v) => v))
+            .subscribe(() => {
+                this.initialLoad();
+                this._notifyStatus();
+            });
     }
 
     isReady(): boolean {
@@ -193,7 +179,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
             return this.getObjectIdsForSearchString(searchString, propertyName);
 
         return this.isReadyObservable()
-            .first()
+            .pipe(first())
             .toPromise()
             .then(() =>
                 this.getObjectIdsForSearchString(searchString, propertyName)
@@ -202,7 +188,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
 
     private _notifyStatus(): void {
         this._status.cacheForOfflineEnabled =
-            this.offlineConfig.cacheChunksForOffline;
+            this.deviceCacheControllerService.cachingEnabled;
         this._status.initialLoadComplete = this.index.initialLoadComplete;
 
         this._status.loadProgress = Object.keys(
@@ -214,6 +200,15 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
             ).length;
 
         this._statusSubject.next(this._status);
+
+        const status = new OfflineCacheStatusTuple();
+        status.pluginName = "peek_core_search";
+        status.indexName = "Keyword Index";
+        status.loadingQueueCount = this._status.loadProgress;
+        status.totalLoadedCount = this._status.loadTotal;
+        status.lastCheckDate = new Date();
+        status.initialFullLoadComplete = this._status.initialLoadComplete;
+        this.deviceCacheControllerService.updateCachingStatus(status);
     }
 
     /** Initial load
@@ -248,21 +243,21 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
                 this,
                 clientSearchIndexWatchUpdateFromDeviceFilt
             )
-            .takeUntil(this.onDestroyEvent)
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
                 this.processSearchIndexesFromServer(payloadEnvelope);
             });
 
         // If the vortex service comes back online, update the watch grids.
         this.vortexStatusService.isOnline
-            .filter((isOnline) => isOnline == true)
-            .takeUntil(this.onDestroyEvent)
+            .pipe(filter((isOnline) => isOnline == true))
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe(() => this.askServerForUpdates());
     }
 
     private areWeTalkingToTheServer(): boolean {
         return (
-            this.offlineConfig.cacheChunksForOffline &&
+            this.deviceCacheControllerService.cachingEnabled &&
             this.vortexStatusService.snapshot.isOnline
         );
     }
@@ -324,7 +319,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
 
         for (let key of keysNeedingUpdate) {
             indexChunk.updateDateByChunkKey[key] =
-                this.index.updateDateByChunkKey[key];
+                this.index.updateDateByChunkKey[key] || "";
             count++;
 
             if (count == this.UPDATE_CHUNK_FETCH_SIZE) {
@@ -414,19 +409,26 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
      * Stores the index bucket in the local db.
      */
     private storeSearchIndexChunkTuples(
-        tuplesToSave: EncodedSearchIndexChunkTuple[]
+        encodedSearchIndexChunkTuples: EncodedSearchIndexChunkTuple[]
     ): Promise<void> {
-        const Selector = SearchIndexChunkTupleSelector;
-        const batchStore: TupleStorageBatchSaveArguments[] = [];
+        let retPromise: any;
+        retPromise = this.storage.transaction(true).then((tx) => {
+            let promises = [];
 
-        for (const tuple of tuplesToSave) {
-            batchStore.push({
-                tupleSelector: new Selector(tuple.chunkKey),
-                vortexMsg: tuple.encodedData,
-            });
-        }
+            for (let encodedSearchIndexChunkTuple of encodedSearchIndexChunkTuples) {
+                promises.push(
+                    tx.saveTuplesEncoded(
+                        new SearchIndexChunkTupleSelector(
+                            encodedSearchIndexChunkTuple.chunkKey
+                        ),
+                        encodedSearchIndexChunkTuple.encodedData
+                    )
+                );
+            }
 
-        return this.storage.batchSaveTuplesEncoded(batchStore);
+            return Promise.all(promises).then(() => tx.close());
+        });
+        return retPromise;
     }
 
     /** Get Object IDs When Ready
@@ -439,9 +441,14 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
         searchString: string,
         propertyName: string | null
     ): Promise<number[]> {
-        // Split the keywords into full keywords
+        console.log(`Started search with string |${searchString}|`);
+
+        // ---------------
+        // Search for fulls
         const fullKwTokens = splitFullKeywords(searchString);
 
+        console.log(`Searching for full tokens |${fullKwTokens}|`);
+
         // If there are no tokens then return nothing
         if (fullKwTokens == null || fullKwTokens.length == 0) {
             return [];
@@ -466,6 +473,11 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
         const resultsByPartialKw: { [token: string]: number[] } =
             await this.loadObjectIdsFromIndex(partialKwTokens, propertyName);
 
+        console.log("Found results for partial tokens |${resultsByPartialKw}|");
+
+        // ---------------
+        // Process the results
+
         // Merge the results
         const results = {};
         Object.assign(results, resultsByFullKw);
@@ -493,7 +505,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
         tokens: string[],
         propertyName: string | null
     ): Promise<{ [token: string]: number[] }> {
-        const tokensByChunkKey: { [chunkKey: number]: string[] } = {};
+        const tokensByChunkKey: { [chunkKey: string]: string[] } = {};
 
         // Group the keys for
         for (let token of tokens) {
@@ -505,11 +517,10 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
         const promises = [];
         for (let chunkKey of Object.keys(tokensByChunkKey)) {
             const tokensInChunk = tokensByChunkKey[chunkKey];
-            const chunkKeyInt = parseInt(chunkKey.toString());
             promises.push(
                 this.getObjectIdsForKeyword(
                     propertyName,
-                    chunkKeyInt,
+                    chunkKey,
                     tokensInChunk
                 )
             );
@@ -531,7 +542,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
      */
     private async getObjectIdsForKeyword(
         propertyName: string | null,
-        chunkKey: number,
+        chunkKey: string,
         tokens: string[]
     ): Promise<{ [token: string]: number[] }> {
         if (tokens == null || tokens.length == 0) {
