@@ -1,3 +1,5 @@
+import { Observable, Subject } from "rxjs";
+import { filter, first, takeUntil } from "rxjs/operators";
 import { Injectable } from "@angular/core";
 import {
     extend,
@@ -10,7 +12,6 @@ import {
     TupleStorageFactoryService,
     VortexService,
     VortexStatusService,
-    TupleStorageBatchSaveArguments,
 } from "@synerty/vortexjs";
 
 import {
@@ -18,16 +19,17 @@ import {
     searchObjectCacheStorageName,
     searchTuplePrefix,
 } from "../PluginNames";
-
-import { Observable, Subject } from "rxjs";
 import { EncodedSearchObjectChunkTuple } from "./EncodedSearchObjectChunkTuple";
 import { SearchObjectUpdateDateTuple } from "./SearchObjectUpdateDateTuple";
 import { SearchResultObjectTuple } from "../../SearchResultObjectTuple";
 import { SearchResultObjectRouteTuple } from "../../SearchResultObjectRouteTuple";
-import { OfflineConfigTuple } from "../tuples/OfflineConfigTuple";
 import { SearchTupleService } from "../SearchTupleService";
 import { PrivateSearchObjectLoaderStatusTuple } from "./PrivateSearchObjectLoaderStatusTuple";
 import { SearchObjectTypeTuple } from "../../SearchObjectTypeTuple";
+import {
+    DeviceOfflineCacheControllerService,
+    OfflineCacheStatusTuple,
+} from "@peek/peek_core_device";
 
 // ----------------------------------------------------------------------------
 
@@ -45,7 +47,7 @@ const cacheAll = "cacheAll";
  */
 
 class SearchObjectChunkTupleSelector extends TupleSelector {
-    constructor(private chunkKey: number) {
+    constructor(private chunkKey: string) {
         super(searchTuplePrefix + "SearchObjectChunkTuple", { key: chunkKey });
     }
 
@@ -70,7 +72,7 @@ class UpdateDateTupleSelector extends TupleSelector {
  */
 let OBJECT_BUCKET_COUNT = 8192;
 
-function objectIdChunk(objectId: number): number {
+function objectIdChunk(objectId: number): string {
     /** Object ID Chunk
      
      This method creates an int from 0 to MAX, representing the hash bucket for this
@@ -85,7 +87,7 @@ function objectIdChunk(objectId: number): number {
      */
     if (objectId == null) throw new Error("objectId None or zero length");
 
-    return objectId & (OBJECT_BUCKET_COUNT - 1);
+    return (objectId & (OBJECT_BUCKET_COUNT - 1)).toString();
 }
 
 // ----------------------------------------------------------------------------
@@ -115,32 +117,15 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
         new Subject<PrivateSearchObjectLoaderStatusTuple>();
     private _status = new PrivateSearchObjectLoaderStatusTuple();
 
-    private offlineConfig: OfflineConfigTuple = new OfflineConfigTuple();
-
     constructor(
         private vortexService: VortexService,
         private vortexStatusService: VortexStatusService,
         storageFactory: TupleStorageFactoryService,
-        private tupleService: SearchTupleService
+        private tupleService: SearchTupleService,
+        private deviceCacheControllerService: DeviceOfflineCacheControllerService
     ) {
         super();
 
-        this.tupleService.offlineObserver
-            .subscribeToTupleSelector(
-                new TupleSelector(OfflineConfigTuple.tupleName, {}),
-                false,
-                false,
-                true
-            )
-            .takeUntil(this.onDestroyEvent)
-            .filter((v) => v.length != 0)
-            .subscribe((tuples: OfflineConfigTuple[]) => {
-                this.offlineConfig = tuples[0];
-                if (this.offlineConfig.cacheChunksForOffline)
-                    this.initialLoad();
-                this._notifyStatus();
-            });
-
         this.storage = new TupleOfflineStorageService(
             storageFactory,
             new TupleOfflineStorageNameService(searchObjectCacheStorageName)
@@ -149,10 +134,13 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
         this.setupVortexSubscriptions();
         this._notifyStatus();
 
-        // Check for updates every so often
-        Observable.interval(this.OFFLINE_CHECK_PERIOD_MS)
-            .takeUntil(this.onDestroyEvent)
-            .subscribe(() => this.askServerForUpdates());
+        this.deviceCacheControllerService.triggerCachingObservable
+            .pipe(takeUntil(this.onDestroyEvent))
+            .pipe(filter((v) => v))
+            .subscribe(() => {
+                this.initialLoad();
+                this._notifyStatus();
+            });
     }
 
     isReady(): boolean {
@@ -188,14 +176,14 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
             return this.getObjectsWhenReady(objectTypeId, objectIds);
 
         return this.isReadyObservable()
-            .first()
+            .pipe(first())
             .toPromise()
             .then(() => this.getObjectsWhenReady(objectTypeId, objectIds));
     }
 
     private _notifyStatus(): void {
         this._status.cacheForOfflineEnabled =
-            this.offlineConfig.cacheChunksForOffline;
+            this.deviceCacheControllerService.cachingEnabled;
         this._status.initialLoadComplete = this.index.initialLoadComplete;
 
         this._status.loadProgress = Object.keys(
@@ -207,6 +195,15 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
             ).length;
 
         this._statusSubject.next(this._status);
+
+        const status = new OfflineCacheStatusTuple();
+        status.pluginName = "peek_core_search";
+        status.indexName = "Object Index";
+        status.loadingQueueCount = this._status.loadProgress;
+        status.totalLoadedCount = this._status.loadTotal;
+        status.lastCheckDate = new Date();
+        status.initialFullLoadComplete = this._status.initialLoadComplete;
+        this.deviceCacheControllerService.updateCachingStatus(status);
     }
 
     /** Initial load
@@ -241,21 +238,21 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
                 this,
                 clientSearchObjectWatchUpdateFromDeviceFilt
             )
-            .takeUntil(this.onDestroyEvent)
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
                 this.processSearchObjectsFromServer(payloadEnvelope);
             });
 
         // If the vortex service comes back online, update the watch grids.
         this.vortexStatusService.isOnline
-            .filter((isOnline) => isOnline == true)
-            .takeUntil(this.onDestroyEvent)
+            .pipe(filter((isOnline) => isOnline == true))
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe(() => this.askServerForUpdates());
     }
 
     private areWeTalkingToTheServer(): boolean {
         return (
-            this.offlineConfig.cacheChunksForOffline &&
+            this.deviceCacheControllerService.cachingEnabled &&
             this.vortexStatusService.snapshot.isOnline
         );
     }
@@ -317,7 +314,7 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
 
         for (let key of keysNeedingUpdate) {
             indexChunk.updateDateByChunkKey[key] =
-                this.index.updateDateByChunkKey[key];
+                this.index.updateDateByChunkKey[key] || "";
             count++;
 
             if (count == this.UPDATE_CHUNK_FETCH_SIZE) {
@@ -408,19 +405,26 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
      * Stores the index bucket in the local db.
      */
     private storeSearchObjectChunkTuples(
-        tuplesToSave: EncodedSearchObjectChunkTuple[]
+        encodedSearchObjectChunkTuples: EncodedSearchObjectChunkTuple[]
     ): Promise<void> {
-        const Selector = SearchObjectChunkTupleSelector;
-        const batchStore: TupleStorageBatchSaveArguments[] = [];
+        let retPromise: any;
+        retPromise = this.storage.transaction(true).then((tx) => {
+            let promises = [];
 
-        for (const tuple of tuplesToSave) {
-            batchStore.push({
-                tupleSelector: new Selector(tuple.chunkKey),
-                vortexMsg: tuple.encodedData,
-            });
-        }
+            for (let encodedSearchObjectChunkTuple of encodedSearchObjectChunkTuples) {
+                promises.push(
+                    tx.saveTuplesEncoded(
+                        new SearchObjectChunkTupleSelector(
+                            encodedSearchObjectChunkTuple.chunkKey
+                        ),
+                        encodedSearchObjectChunkTuple.encodedData
+                    )
+                );
+            }
 
-        return this.storage.batchSaveTuplesEncoded(batchStore);
+            return Promise.all(promises).then(() => tx.close());
+        });
+        return retPromise;
     }
 
     /** Get Objects When Ready
@@ -433,10 +437,10 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
         objectIds: number[]
     ): Promise<SearchResultObjectTuple[]> {
         let objectIdsByChunkKey: { [key: number]: number[] } = {};
-        let chunkKeys: number[] = [];
+        let chunkKeys: string[] = [];
 
         for (let objectId of objectIds) {
-            let chunkKey: number = objectIdChunk(objectId);
+            let chunkKey: string = objectIdChunk(objectId);
             if (objectIdsByChunkKey[chunkKey] == null)
                 objectIdsByChunkKey[chunkKey] = [];
             objectIdsByChunkKey[chunkKey].push(objectId);
@@ -470,7 +474,7 @@ export class PrivateSearchObjectLoaderService extends NgLifeCycleEvents {
     private getObjectsForObjectIds(
         objectTypeId: number | null,
         objectIds: number[],
-        chunkKey: number
+        chunkKey: string
     ): Promise<SearchResultObjectTuple[]> {
         if (!this.index.updateDateByChunkKey.hasOwnProperty(chunkKey)) {
             console.log(`ObjectIDs: ${objectIds} doesn't appear in the index`);
